==> teamapps-application-server-0.14-sources.jar: org/teamapps/model/controlcenter/NewsBoardMessageTranslationQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface NewsBoardMessageTranslationQuery extends Query<NewsBoardMessageTranslation> {

    static NewsBoardMessageTranslationQuery create() {
        return new UdbNewsBoardMessageTranslationQuery();
    }

    NewsBoardMessageTranslationQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    NewsBoardMessageTranslationQuery parseFullTextFilter(String query, String... fieldNames);

	NewsBoardMessageTranslationQuery metaCreationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaCreationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaCreatedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaCreatedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaModificationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaModificationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaModifiedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaModifiedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaDeletionDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaDeletionDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaDeletedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaDeletedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaRestoreDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaRestoreDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaRestoredBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaRestoredBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery filterMessage(NewsBoardMessageQuery query);

	NewsBoardMessageTranslationQuery message(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMessage(NumericFilter filter);

	NewsBoardMessageTranslationQuery language(TextFilter filter);

	NewsBoardMessageTranslationQuery orLanguage(TextFilter filter);

	NewsBoardMessageTranslationQuery translation(TextFilter filter);

	NewsBoardMessageTranslationQuery orTranslation(TextFilter filter);


    NewsBoardMessageTranslationQuery andOr(NewsBoardMessageTranslationQuery... queries);

    NewsBoardMessageTranslationQuery customFilter(Function<NewsBoardMessageTranslation, Boolean> customFilter);

    List<NewsBoardMessageTranslation> execute();

    List<NewsBoardMessageTranslation> executeOnDeletedRecords();

    NewsBoardMessageTranslation executeExpectSingleton();

    BitSet executeToBitSet();

    List<NewsBoardMessageTranslation> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageTranslation> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}

==> teamapps-application-server-0.15-sources.jar: org/teamapps/model/controlcenter/NewsBoardMessageTranslationQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface NewsBoardMessageTranslationQuery extends Query<NewsBoardMessageTranslation> {

    static NewsBoardMessageTranslationQuery create() {
        return new UdbNewsBoardMessageTranslationQuery();
    }

    NewsBoardMessageTranslationQuery id(Integer... ids);

    NewsBoardMessageTranslationQuery id(BitSet ids);

    NewsBoardMessageTranslationQuery id(Collection<Integer> ids);

    NewsBoardMessageTranslationQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    NewsBoardMessageTranslationQuery parseFullTextFilter(String query, String... fieldNames);

	NewsBoardMessageTranslationQuery metaCreationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaCreationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaCreatedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaCreatedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaModificationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaModificationDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaModifiedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaModifiedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaDeletionDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaDeletionDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaDeletedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaDeletedBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaRestoreDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaRestoreDate(NumericFilter filter);

	NewsBoardMessageTranslationQuery metaRestoredBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMetaRestoredBy(NumericFilter filter);

	NewsBoardMessageTranslationQuery filterMessage(NewsBoardMessageQuery query);

	NewsBoardMessageTranslationQuery message(NumericFilter filter);

	NewsBoardMessageTranslationQuery orMessage(NumericFilter filter);

	NewsBoardMessageTranslationQuery language(TextFilter filter);

	NewsBoardMessageTranslationQuery orLanguage(TextFilter filter);

	NewsBoardMessageTranslationQuery translation(TextFilter filter);

	NewsBoardMessageTranslationQuery orTranslation(TextFilter filter);


    NewsBoardMessageTranslationQuery andOr(NewsBoardMessageTranslationQuery... queries);

    NewsBoardMessageTranslationQuery customFilter(Function<NewsBoardMessageTranslation, Boolean> customFilter);

    List<NewsBoardMessageTranslation> execute();

    List<NewsBoardMessageTranslation> executeOnDeletedRecords();

    NewsBoardMessageTranslation executeExpectSingleton();

    BitSet executeToBitSet();

    List<NewsBoardMessageTranslation> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageTranslation> execute(boolean deletedRecords, String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageTranslation> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}
